( cd usr/include ; rm -rf db.h )
( cd usr/include ; ln -sf db3/db.h db.h )
( cd usr/lib ; rm -rf libdb-3.3.so )
( cd usr/lib ; ln -sf /lib/libdb-3.3.so libdb-3.3.so )
( cd usr/lib ; rm -rf libdb-3.so )
( cd usr/lib ; ln -sf libdb-3.3.so libdb-3.so )
( cd usr/lib ; rm -rf libdb.so )
( cd usr/lib ; ln -sf libdb-3.3.so libdb.so )
( cd usr/lib ; rm -rf libdb-3.a )
( cd usr/lib ; ln -sf libdb-3.3.a libdb-3.a )
( cd usr/lib ; rm -rf libdb.a )
( cd usr/lib ; ln -sf libdb-3.3.a libdb.a )
